==> dl.php?src=linea21_1_6.zip: linea21/lib/js/functions.js <==
$(document).ready(function() {
	$("a.out").attr("target", "_blank");
	
//	$("#content img").each(
//			function(i) {
//				
//				// we get required data
//				var captiontext = $(this).attr('alt');
//				var outerwidth = $(this).outerWidth();
//				var width = $(this).css('width');
//				var border = $(this).css('border');
//				var marginleft = $(this).css('margin-left');
//				var marginright = $(this).css('margin-right');
//				var margintop = $(this).css('margin-top');
//				var marginbottom = $(this).css('margin-bottom');
//				var float = $(this).css('float');
//
//				// we create a wrapper and style it
//				$(this).wrap('<div class="imgwrapper"></div>');
//				$(this).parent().append('<div class="caption">' + captiontext + '</div>');
//				
//				// we calculate dynamically the width of the caption
//				var pleft = $('.caption').css('padding-left').replace('px', '');
//				var pright = $('.caption').css('padding-right').replace('px', '');
//
//				var caption_style = 'width:' + (outerwidth - pleft -pright) +'px';
//				var wrapper_style = 'float:' + float + ';margin-left:' + marginleft + ';margin-right:' + marginright + ';margin-top:' + margintop + ';margin-bottom:' + marginbottom + ';width:' + outerwidth + 'px;';
//				
//				// finally we apply styles
//				$(this).parent().attr('style', wrapper_style);
//				$(this).next().attr('style', caption_style);
//				
//				// we remove margin on image
//				$(this).css('margin', '0');
//
//				// we bind behavior
//				$(this).parent().bind({
//					mouseenter : function(e) {
//						$(this).find("div.caption").show();
//					},
//					mouseleave : function(e) {
//						$(this).find("div.caption").hide();
//					}
//				});
//
//			});
});

function cookieAlert(container, msg) {
	$(document).ready(function() {
		if (!navigator.cookieEnabled) {
			$(container).empty();
			$(container).append('<p class="error">' + msg + '</p>');
		}
		return true;
	});
}

==> dl.php?src=linea21_2_0_0.zip: linea21/lib/js/functions.js <==
$(document).ready(function() {
	
	$("a.out").attr("target", "_blank");
	
	$("a[href^='#footnote']").each(function(){
	  var hrefval = window.location.href + $(this).attr('href');
	  $(this).attr('href', hrefval);
	});
	

//	$("#content img").each(
//			function(i) {
//				
//				// we get required data
//				var captiontext = $(this).attr('alt');
//				var outerwidth = $(this).outerWidth();
//				var width = $(this).css('width');
//				var border = $(this).css('border');
//				var marginleft = $(this).css('margin-left');
//				var marginright = $(this).css('margin-right');
//				var margintop = $(this).css('margin-top');
//				var marginbottom = $(this).css('margin-bottom');
//				var float = $(this).css('float');
//
//				// we create a wrapper and style it
//				$(this).wrap('<div class="imgwrapper"></div>');
//				$(this).parent().append('<div class="caption">' + captiontext + '</div>');
//				
//				// we calculate dynamically the width of the caption
//				var pleft = $('.caption').css('padding-left').replace('px', '');
//				var pright = $('.caption').css('padding-right').replace('px', '');
//
//				var caption_style = 'width:' + (outerwidth - pleft -pright) +'px';
//				var wrapper_style = 'float:' + float + ';margin-left:' + marginleft + ';margin-right:' + marginright + ';margin-top:' + margintop + ';margin-bottom:' + marginbottom + ';width:' + outerwidth + 'px;';
//				
//				// finally we apply styles
//				$(this).parent().attr('style', wrapper_style);
//				$(this).next().attr('style', caption_style);
//				
//				// we remove margin on image
//				$(this).css('margin', '0');
//
//				// we bind behavior
//				$(this).parent().bind({
//					mouseenter : function(e) {
//						$(this).find("div.caption").show();
//					},
//					mouseleave : function(e) {
//						$(this).find("div.caption").hide();
//					}
//				});
//
//			});
});

function getRandomInt(min, max) {
    return Math.floor(Math.random() * (max - min + 1)) + min;
}

function number_f(nb) {
	nb = nb.toString().replace('.', ',');
	nb = nb.replace(/\B(?=(\d{3})+(?!\d))/g, " ");
	return nb;
}

function cookieAlert(container, msg) {
	$(document).ready(function() {
		if (!navigator.cookieEnabled) {
			$(container).empty();
			$(container).append('<p class="error">' + msg + '</p>');
		}
		return true;
	});
}
